import setuptools


setuptools.setup(
    name="namphan", # Replace with your own username
    version="0.0.1",
    author="Revotech",
    author_email="support@i2g.cloud",
    description="Wilib",
    long_description="Wilib",
    long_description_content_type="text/markdown",
    url="https://github.com/revotechUET/wilibs",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)